#
# spec file for package python-google-resumable-media
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-google-resumable-media
Version:        2.7.0
Release:        4.2
Summary:        Utilities for Google Media Downloads and Resumable Uploads
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/googleapis/google-resumable-media-python
Source:         https://files.pythonhosted.org/packages/source/g/google-resumable-media/google-resumable-media-%{version}.tar.gz
BuildRequires:  %{python_module google-auth}
BuildRequires:  %{python_module google-crc32c}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.18.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-crc32c
Recommends:     python-aiohttp
Recommends:     python-requests >= 2.18.0
BuildArch:      noarch
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-google-resumable-media < %{version}
%endif
%python_subpackages

%description
Utilities for Google Media Downloads and Resumable Uploads

%prep
%setup -q -n google-resumable-media-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTEST_ADDOPTS="--import-mode=importlib"
# skip online tests
donttest="test_brotli"
donttest="$donttest or test_constructor"
donttest="$donttest or test_decompress"
%pytest tests/unit -k "not ($donttest)"

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/google_resumable_media*-info
%{python_sitelib}/google/resumable_media*
%{python_sitelib}/google/_async_resumable_media*

%changelog
* Tue Mar  5 2024 Robert Schweikert <rjschwei@suse.com>
- Obsolete Python 3.6 build for SLE 15 SP4 and openSUSE Leap 15.4 and later
* Mon Feb 26 2024 Robert Schweikert <rjschwei@suse.com>
- Version update in SLE 15 SP4 and later (jsc#PED-6697)
- Add %%{?sle15_python_module_pythons}
* Thu Jan  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.7.0
  * Add support for Python 3.12 (#407)
  * Support brotli encoding (#403)
- Skip online tests
  * test_brotli
  * test_constructor
  * test_decompress
* Tue Sep 12 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.6.0
  Features
  * Add support for concurrent XML MPU uploads (#395)
  * Introduce compatibility with native namespace packages (#385)
  Bug Fixes
  * Add google-auth to aiohttp extra (#386)
- Update file pattern in %%files section
* Thu May 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.5.0
  Features
  * Add support to retry known connection errors (#375)
* Tue Mar  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.4.1
  Bug Fixes
  * Avoid validating checksums for partial responses (#361)
- Drop patches for issues fixed upstream
  * python-google-resumable-media-no-mock.patch
* Mon Oct 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.4.0
  Features
  * Handle interrupted downloads with decompressive transcoding (#346)
  Bug Fixes
  * Allow recover to check the status of upload regardless of state (#343)
  * Require python 3.7+ (#337) (942665f)
  * Use unittest.mock (#329) (82f9769)
  Documentation
  * Fix changelog header to consistent size (#331) (7b1dc9c)
- Refresh patches for new version
  * python-google-resumable-media-no-mock.patch
* Thu Jun  9 2022 pgajdos@suse.com
- version update to 2.3.3
  * retry client side requests timeout (#319) (d0649c7)
- added patches
  https://github.com/googleapis/google-resumable-media-python/commit/82f9769f3368404d1854dd22eeed34eeb25ea835
  + python-google-resumable-media-no-mock.patch
* Fri Apr  8 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.3.2
  Bug Fixes
  * append existing headers in prepare_initiate_request (#314)
- from version 2.3.1
  Bug Fixes
  * include existing headers in prepare request (#309)
- from version 2.3.0
  Features
  * safely resume interrupted downloads (#294)
- from version 2.2.1
  Bug Fixes
  * don't overwrite user-agent on requests (42b380e)
- from version 2.2.0
  Features
  * add 'py.typed' declaration file (#287)
  * add support for signed resumable upload URLs (#290)
  Bug Fixes
  * add user-agent on requests (#295)
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * add support for Python 3.10
  * Include ConnectionError and urllib3 exception as retriable
* Thu Sep 30 2021 Matej Cepl <mcepl@suse.com>
- Changing pytest's import-mode=importlib seems to make the test
  suite working as well.
* Tue Sep 28 2021 Matej Cepl <mcepl@suse.com>
- Run test suite correctly (from tests/ directory moved elsewhere) (bsc#1197841)
* Tue Aug 31 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.0.0
  * drop Python 2.7 support
  * retry ConnectionError and similar errors that occur mid-download
- from version 1.3.3
  * revert "fix: add retry coverage to the streaming portion of a download"
- from version 1.3.2
  * add retry coverage to the streaming portion of a download
- from version 1.3.1
  * **deps:** require six>=1.4.0
- Disable Python2 builds
- Update BuildRequires and Requires from setup.py
* Mon Aug  2 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add Requires on python-google-crc32c.
- Remove aiohttp from BuildRequires, and add it to Recommends.
* Tue Jun 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Be more specific about included filepaths in %%files
- Add Requires on python-google-filesystem, and stop including a file it
  now ships.
* Fri Jun  4 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.3.0:
  - allow RetryStrategy to be configured with a custom initial
    wait and multiplier
  - add support for Python 3.9, drop support for Python 3.5
  - add retries for 'requests.ConnectionError'
  - add _async_resumable_media experimental support
  - allow space in checksum header
  - lint: blacken 5 files
  - bump 'google-crc32c >= 1.0'
  - pin 'google-crc32c < 0.2dev'
  - update docs build (via synth)
  - use googleapis.dev docs link
  - add configurable checksum support for uploads
  - add customizable timeouts to upload/download methods
  - add configurable crc32c checksumming for downloads
  - add templates for python samples projects
  - update client_documentation link
  - updated CHANGELOG.md
  - updated setup.py
* Wed Mar 17 2021 Steve Kowalik <steven.kowalik@suse.com>
- To enable the test suite to import the namespace package, touch
  __init__.py
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.5.0
  * Add raw download classes.
* Thu Sep 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.1:
  * Revert "Always use raw response data. (#87)" (#103)
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.0:
  * Require 200 response for initial resumable upload request. (#95)
  * Use response as variable for object returned from http_request. (#98)
  * Further DRY request dependency pins. (#96)
  * Finish download on seeing 416 response with zero byte range. (#86)
  * Always use raw response data. (#87)
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.2:
  * Using str instead of repr for multipart boundary.
  * Making requests a strict dependency for the requests subpackage.
- Really run tests
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Sep 12 2018 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 0.3.1)
